@@ -34,5 +34,10 @@ class TestSequenceFunctions(unittest.TestCase):
         sub_location = self.api.get_sublocations(location['id'])
         self.assertTrue('id', sub_location)
 
+  def test_getUsers(self):
+    specialusers = self.api.get_users(group='WW_IT-SWG-Config-Z-App-Disable-On-VPN')
+    print(specialusers)
+
+
 if __name__ == "__main__":
   unittest.main()
\ No newline at end of file
