@@ -1,3 +1,3 @@
 from .zia import *
 
-__all__ = ['api']
\ No newline at end of file
+__all__ = ['zia']
\ No newline at end of file
